@@ -193,10 +193,16 @@ class AppStore(gtk.GenericTreeModel):
                     self.pkgname_index_map[app.pkgname] = []
                 self.pkgname_index_map[app.pkgname].append(i)
 
+    def clear(self):
+        self.apps = []
+        self.app_index_map.clear()
+        self.pkgname_index_map.clear()
+
     def is_filtered_out(self, filter, doc):
         """ apply filter and return True if the package is filtered out """
         pkgname = self.db.get_pkgname(doc)
         return not filter.filter(doc, pkgname)
+
     # internal helper
     def _get_searches_sort_mode(self):
         mode = self.SEARCHES_SORTED_BY_POPCON
@@ -937,6 +943,22 @@ class AppView(gtk.TreeView):
         self.backend.connect("transaction-finished", self._on_transaction_finished)
         self.backend.connect("transaction-stopped", self._on_transaction_stopped)
 
+    def clear_model(self):
+        """ clear the model by deleting the old model """
+        # clear the model harder, we have a memleak otherwise
+        # if we don't do a explicit del
+        old_model = self.get_model()
+        self.set_model(None)
+        if old_model is None:
+            return
+        # *ugh* deactivate the old model because otherwise it keeps
+        # getting progress_changed events and eats CPU time until its
+        # garbage collected
+        old_model.active = False
+        old_model.clear()
+        del old_model
+
+
     def is_action_in_progress_for_selected_app(self):
         """
         return True if an install or remove of the current package
