@@ -191,18 +191,9 @@ class AvailablePane(SoftwarePane):
         # build query
         query = self._get_query()
         logging.debug("availablepane query: %s" % query)
-
-        old_model = self.app_view.get_model()
-        if old_model is not None:
-            # *ugh* deactivate the old model because otherwise it keeps
-            # getting progress_changed events and eats CPU time until its
-            # garbage collected
-            old_model.active = False
-            self.app_view.set_model(None)
-            while gtk.events_pending():
-                gtk.main_iteration()
-
-        logging.debug("availablepane query: %s" % query)
+        # deactivate the old model, otherwise we have a memleak and
+        # a cpu leak
+        self.app_view.clear_model()
         # create new model and attach it
         seq_nr = self.refresh_seq_nr
         if self.app_view.window:
