@@ -157,9 +157,10 @@ class ViewSwitcher(gtk.TreeView):
         we need to reselect it
         """
         model = self.get_model()
-        channel_iter_to_select = model.get_channel_iter_for_name(self.selected_channel_name)
-        if channel_iter_to_select:
-            self.set_cursor(model.get_path(channel_iter_to_select))
+        if model:
+            channel_iter_to_select = model.get_channel_iter_for_name(self.selected_channel_name)
+            if channel_iter_to_select:
+                self.set_cursor(model.get_path(channel_iter_to_select))
 
 class ViewSwitcherList(gtk.TreeStore):
     
@@ -311,7 +312,8 @@ class ViewSwitcherList(gtk.TreeStore):
             logging.debug("channel_origin: %s" % channel_origin)
             other_channel_list.append((channel_name, channel_origin))
         
-        dist_channel = []
+        dist_channel = None
+        partner_channel = None
         ppa_channels = []
         other_channels = []
         unknown_channel = []
@@ -328,6 +330,12 @@ class ViewSwitcherList(gtk.TreeStore):
                                                 channel_origin,
                                                 None,
                                                 filter_required=True))
+            elif channel_name == "Partner archive":
+                partner_channel = SoftwareChannel(self.icons, 
+                                                  channel_name,
+                                                  channel_origin,
+                                                  "partner", 
+                                                  filter_required=True)
             elif channel_origin and channel_origin.startswith("LP-PPA"):
                 ppa_channels.append(SoftwareChannel(self.icons, 
                                                     channel_name,
@@ -339,23 +347,12 @@ class ViewSwitcherList(gtk.TreeStore):
                                                       channel_name,
                                                       channel_origin,
                                                       None))
-        # FIXME: do not hardcode this, check instead for 
-        #        self.db.xapiandb.allterms("AH") and add all of those
-        #        and provide a mechanism in the channel to check
-        #        both origin (XAO) and channel name from app-install (AH)
-        # FIXME2: pass the AH name as well so that we do not need to special
-        #         case the AH query for partner
-        # also get the partner repository
-        partner_channel = SoftwareChannel(self.icons, 
-                                          distro_channel_name,
-                                          None,
-                                          "partner", 
-                                          filter_required=True)
-        
         # set them in order
         channels = []
-        channels.append(dist_channel)
-        channels.append(partner_channel)
+        if dist_channel is not None:
+            channels.append(dist_channel)
+        if partner_channel is not None:
+            channels.append(partner_channel)
         channels.extend(ppa_channels)
         channels.extend(other_channels)
         channels.extend(unknown_channel)
